FbBatch class

A wrapper class for Firestore batch operations.

Provides a simplified interface for performing batch writes to Firestore. Use this class when you need to perform multiple write operations atomically.

Constructors

FbBatch.create(WriteBatch _batch, FirebaseFirestore _firestore)
Creates a new FbBatch instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

commit() Future<void>
Commits the batch operations.
delete(String path) → void
Deletes the document at the specified path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String path, Map<String, dynamic> data, {bool merge = false}) → void
Sets data on a document with the specified path.
toString() String
A string representation of this object.
inherited
update(String path, Map<String, dynamic> data) → void
Updates fields in the document.

Operators

operator ==(Object other) bool
The equality operator.
inherited