commit method
Commits the batch operations.
Returns a Future that completes when the batch is committed.
Implementation
Future<void> commit() async {
await _batch.commit();
}
Commits the batch operations.
Returns a Future that completes when the batch is committed.
Future<void> commit() async {
await _batch.commit();
}