set method
Sets data on a document with the specified path.
path The document path (e.g., 'users/123')
data The data to set
merge Whether to merge the data with existing document data
Implementation
void set(String path, Map<String, dynamic> data, {bool merge = false}) {
_batch.set(_firestore.doc(path), data, SetOptions(merge: merge));
}